<<<<<<< HEAD
NOTIFATOR
==============

merges

- rpihat
- an older attempt notify.py

*in development*
=======
# Project: notifator 
 
## Module: telegram 
 
>>>>>>> 636d65dfce204c5b72894b51cc419cddcbc417cf
